==> marketplace-constants-0.1.4.6.tar.gz: marketplace-constants-0.1.4.6/mpconstants/regions/fi.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Arabiemiirikunnat',
 u'af': u'Afganistan',
 u'ag': u'Antigua ja Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Alankomaiden Antillit',
 u'ao': u'Angola',
 u'aq': u'Antarktis',
 u'ar': u'Argentiina',
 u'as': u'Amerikan Samoa',
 u'at': u'It\xe4valta',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Ahvenanmaa',
 u'az': u'Azerbaid\u017ean',
 u'ba': u'Bosnia ja Hertsegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei',
 u'bo': u'Bolivia',
 u'br': u'Brasilia',
 u'bs': u'Bahama',
 u'bt': u'Bhutan',
 u'bv': u"Bouvet'nsaari",
 u'bw': u'Botswana',
 u'by': u'Valko-Ven\xe4j\xe4',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kookossaaret',
 u'cd': u'Kongon demokraattinen tasavalta',
 u'cf': u'Keski-Afrikan tasavalta',
 u'cg': u'Kongon tasavalta',
 u'ch': u'Sveitsi',
 u'ci': u'Norsunluurannikko',
 u'ck': u'Cookinsaaret',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'Kiina',
 u'co': u'Kolumbia',
 u'cr': u'Costa Rica',
 u'cu': u'Kuuba',
 u'cv': u'Kap Verde',
 u'cx': u'Joulusaari',
 u'cy': u'Kypros',
 u'cz': u'T\u0161ekki',
 u'de': u'Saksa',
 u'dj': u'Djibouti',
 u'dk': u'Tanska',
 u'dm': u'Dominica',
 u'do': u'Dominikaaninen tasavalta',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Viro',
 u'eg': u'Egypti',
 u'eh': u'L\xe4nsi-Sahara',
 u'er': u'Eritrea',
 u'es': u'Espanja',
 u'et': u'Etiopia',
 u'fi': u'Suomi',
 u'fj': u'Fid\u017ei',
 u'fk': u'Falklandinsaaret (Malvinassaaret)',
 u'fm': u'Mikronesia',
 u'fo': u'F\xe4rsaaret',
 u'fr': u'Ranska',
 u'ga': u'Gabon',
 u'gb': u'Yhdistynyt kuningaskunta',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Ranskan Guayana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Gr\xf6nlanti',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'P\xe4iv\xe4ntasaajan Guinea',
 u'gr': u'Kreikka',
 u'gs': u'Etel\xe4-Georgia ja Etel\xe4iset Sandwichsaaret',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hongkong',
 u'hm': u'Heard ja McDonaldinsaaret',
 u'hn': u'Honduras',
 u'hr': u'kroatia',
 u'ht': u'Haiti',
 u'hu': u'Unkari',
 u'id': u'Indonesia',
 u'ie': u'Irlanti',
 u'il': u'Israel',
 u'im': u'Mansaari',
 u'in': u'Intia',
 u'io': u'Brittil\xe4inen Intian valtameren alue',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Islanti',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaika',
 u'jo': u'Jordania',
 u'jp': u'Japani',
 u'ke': u'Kenia',
 u'kg': u'Kirgisia',
 u'kh': u'Kambod\u017ea',
 u'ki': u'Kiribati',
 u'km': u'Komorit',
 u'kn': u'Saint Kitts ja Nevis',
 u'kp': u'Pohjois-Korea',
 u'kr': u'Etel\xe4-Korea',
 u'kw': u'Kuwait',
 u'ky': u'Caymansaaret',
 u'kz': u'Kazakstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Liettua',
 u'lu': u'Luxemburg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Marokko',
 u'mc': u'Monaco',
 u'md': u'Moldovan tasavalta',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Marshallinsaaret',
 u'mk': u'Entinen Jugoslavian tasavalta Makedonia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Pohjois-Mariaanit',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Malediivit',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Malesia',
 u'mz': u'Mosambik',
 u'na': u'Namibia',
 u'nc': u'Uusi-Kaledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolkinsaari',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Alankomaat',
 u'no': u'Norja',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Uusi-Seelanti',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Ranskan Polynesia',
 u'pg': u'Papua-Uusi-Guinea',
 u'ph': u'Filippiinit',
 u'pk': u'Pakistan',
 u'pl': u'Puola',
 u'pm': u'Saint-Pierre ja Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Palestiina',
 u'pt': u'Portugali',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'R\xe9union',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Ven\xe4j\xe4',
 u'rw': u'Ruanda',
 u'sa': u'Saudi-Arabia',
 u'sb': u'Salomonsaaret',
 u'sc': u'Seychellit',
 u'sd': u'Sudan',
 u'se': u'Ruotsi',
 u'sg': u'Singapore',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard ja Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'S\xe3o Tom\xe9 ja Pr\xedncipe',
 u'sv': u'El Salvador',
 u'sy': u'Syyria',
 u'sz': u'Swazimaa',
 u'tc': u'Turks- ja Caicossaaret',
 u'td': u'T\u0161ad',
 u'tf': u'Ranskan etel\xe4iset alueet',
 u'tg': u'Togo',
 u'th': u'Thaimaa',
 u'tj': u'Tad\u017eikistan',
 u'tk': u'Tokelau',
 u'tl': u'It\xe4-Timor',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turkki',
 u'tt': u'Trinidad ja Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tansania',
 u'ua': u'Ukraina',
 u'ug': u'Uganda',
 u'um': u'Yhdysvaltain pienet erillissaaret',
 u'us': u'Yhdysvallat',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vatikaani',
 u'vc': u'Saint Vincent ja Grenadiinit',
 u've': u'Venezuela',
 u'vg': u'Brittil\xe4iset Neitsytsaaret',
 u'vi': u'Yhdysvaltain Neitsytsaaret',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis ja Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Etel\xe4-Afrikka',
 u'zm': u'Sambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.4.0.tar.gz: marketplace-constants-0.4.0/mpconstants/regions/fi.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Arabiemiirikunnat',
 u'af': u'Afganistan',
 u'ag': u'Antigua ja Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Alankomaiden Antillit',
 u'ao': u'Angola',
 u'aq': u'Antarktis',
 u'ar': u'Argentiina',
 u'as': u'Amerikan Samoa',
 u'at': u'It\xe4valta',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Ahvenanmaa',
 u'az': u'Azerbaid\u017ean',
 u'ba': u'Bosnia ja Hertsegovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrain',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermuda',
 u'bn': u'Brunei',
 u'bo': u'Bolivia',
 u'br': u'Brasilia',
 u'bs': u'Bahama',
 u'bt': u'Bhutan',
 u'bv': u"Bouvet'nsaari",
 u'bw': u'Botswana',
 u'by': u'Valko-Ven\xe4j\xe4',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kookossaaret',
 u'cd': u'Kongon demokraattinen tasavalta',
 u'cf': u'Keski-Afrikan tasavalta',
 u'cg': u'Kongon tasavalta',
 u'ch': u'Sveitsi',
 u'ci': u'Norsunluurannikko',
 u'ck': u'Cookinsaaret',
 u'cl': u'Chile',
 u'cm': u'Kamerun',
 u'cn': u'Kiina',
 u'co': u'Kolumbia',
 u'cr': u'Costa Rica',
 u'cu': u'Kuuba',
 u'cv': u'Kap Verde',
 u'cx': u'Joulusaari',
 u'cy': u'Kypros',
 u'cz': u'T\u0161ekki',
 u'de': u'Saksa',
 u'dj': u'Djibouti',
 u'dk': u'Tanska',
 u'dm': u'Dominica',
 u'do': u'Dominikaaninen tasavalta',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Viro',
 u'eg': u'Egypti',
 u'eh': u'L\xe4nsi-Sahara',
 u'er': u'Eritrea',
 u'es': u'Espanja',
 u'et': u'Etiopia',
 u'fi': u'Suomi',
 u'fj': u'Fid\u017ei',
 u'fk': u'Falklandinsaaret (Malvinassaaret)',
 u'fm': u'Mikronesia',
 u'fo': u'F\xe4rsaaret',
 u'fr': u'Ranska',
 u'ga': u'Gabon',
 u'gb': u'Yhdistynyt kuningaskunta',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Ranskan Guayana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Gr\xf6nlanti',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'P\xe4iv\xe4ntasaajan Guinea',
 u'gr': u'Kreikka',
 u'gs': u'Etel\xe4-Georgia ja Etel\xe4iset Sandwichsaaret',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hongkong',
 u'hm': u'Heard ja McDonaldinsaaret',
 u'hn': u'Honduras',
 u'hr': u'kroatia',
 u'ht': u'Haiti',
 u'hu': u'Unkari',
 u'id': u'Indonesia',
 u'ie': u'Irlanti',
 u'il': u'Israel',
 u'im': u'Mansaari',
 u'in': u'Intia',
 u'io': u'Brittil\xe4inen Intian valtameren alue',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Islanti',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaika',
 u'jo': u'Jordania',
 u'jp': u'Japani',
 u'ke': u'Kenia',
 u'kg': u'Kirgisia',
 u'kh': u'Kambod\u017ea',
 u'ki': u'Kiribati',
 u'km': u'Komorit',
 u'kn': u'Saint Kitts ja Nevis',
 u'kp': u'Pohjois-Korea',
 u'kr': u'Etel\xe4-Korea',
 u'kw': u'Kuwait',
 u'ky': u'Caymansaaret',
 u'kz': u'Kazakstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Saint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Liettua',
 u'lu': u'Luxemburg',
 u'lv': u'Latvia',
 u'ly': u'Libya',
 u'ma': u'Marokko',
 u'mc': u'Monaco',
 u'md': u'Moldovan tasavalta',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Marshallinsaaret',
 u'mk': u'Entinen Jugoslavian tasavalta Makedonia',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Macao',
 u'mp': u'Pohjois-Mariaanit',
 u'mq': u'Martinique',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Malediivit',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Malesia',
 u'mz': u'Mosambik',
 u'na': u'Namibia',
 u'nc': u'Uusi-Kaledonia',
 u'ne': u'Niger',
 u'nf': u'Norfolkinsaari',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Alankomaat',
 u'no': u'Norja',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Uusi-Seelanti',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Ranskan Polynesia',
 u'pg': u'Papua-Uusi-Guinea',
 u'ph': u'Filippiinit',
 u'pk': u'Pakistan',
 u'pl': u'Puola',
 u'pm': u'Saint-Pierre ja Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Rico',
 u'ps': u'Palestiina',
 u'pt': u'Portugali',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'R\xe9union',
 u'ro': u'Romania',
 u'rs': u'Serbia',
 u'ru': u'Ven\xe4j\xe4',
 u'rw': u'Ruanda',
 u'sa': u'Saudi-Arabia',
 u'sb': u'Salomonsaaret',
 u'sc': u'Seychellit',
 u'sd': u'Sudan',
 u'se': u'Ruotsi',
 u'sg': u'Singapore',
 u'sh': u'Saint Helena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard ja Jan Mayen',
 u'sk': u'Slovakia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Suriname',
 u'st': u'S\xe3o Tom\xe9 ja Pr\xedncipe',
 u'sv': u'El Salvador',
 u'sy': u'Syyria',
 u'sz': u'Swazimaa',
 u'tc': u'Turks- ja Caicossaaret',
 u'td': u'T\u0161ad',
 u'tf': u'Ranskan etel\xe4iset alueet',
 u'tg': u'Togo',
 u'th': u'Thaimaa',
 u'tj': u'Tad\u017eikistan',
 u'tk': u'Tokelau',
 u'tl': u'It\xe4-Timor',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turkki',
 u'tt': u'Trinidad ja Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tansania',
 u'ua': u'Ukraina',
 u'ug': u'Uganda',
 u'um': u'Yhdysvaltain pienet erillissaaret',
 u'us': u'Yhdysvallat',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vatikaani',
 u'vc': u'Saint Vincent ja Grenadiinit',
 u've': u'Venezuela',
 u'vg': u'Brittil\xe4iset Neitsytsaaret',
 u'vi': u'Yhdysvaltain Neitsytsaaret',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis ja Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Etel\xe4-Afrikka',
 u'zm': u'Sambia',
 u'zw': u'Zimbabwe'}
